View source: R/screen-survival.R
| diagnosis_survival | R Documentation |
Survival probability for RITA Screening
diagnosis_survival(
undiagnosed,
tslt,
ever_hiv_test,
hiv,
weights,
n = 365 * 5,
population = c("undiagnosed", "negative")
)
undiagnosed |
A logical vector indicating if an individual has never been diagnosed as HIV+. |
tslt |
Time since last test in days |
ever_hiv_test |
A logical vector indicating whether an individual has ever had an HIV test |
hiv |
HIV positive status. |
weights |
Survey weights |
n |
Number of days to calculate |
population |
If undiagnosed, the testing histories of undiagnosed HIV+ people are used. If negative, the HIV- population is used. |
A vector where the ith element is the probability that an individual infected i days ago has not been diagnosed.
data("assay_data")
diagnosis_survival(
assay_data$undiagnosed,
assay_data$tslt,
assay_data$ever_hiv_test,
assay_data$hiv,
assay_data$weights,
n=40)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.